from setuptools import setup

setup(name='distribut_mlnd',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['distribut_mlnd'],
      author='Rasmus Toivanen',
      author_email='rasmus.toivanen@hotmail.com',
      zip_safe=False)
